==> experiment_ltt-0.0.2-py3-none-any.whl: experiment/experiment.py <==

def _create_default_instance_table(conn):
    cur = conn.cursor()
    cur.execute('''CREATE TABLE instance (
            id INT AUTO_INCREMENT PRIMARY KEY,
            name TEXT,
            kind TEXT)''')

def _create_default_method_table(conn):
    cur = conn.cursor()
    cur.execute('''CREATE TABLE method(
            id INT AUTO_INCREMENT PRIMARY KEY,
            name TEXT)''')

def _create_default_iteration_table(conn):
    cur = conn.cursor()
    cur.execute('''CREATE TABLE iteration(
            id INT AUTO_INCREMENT PRIMARY KEY,
            best DOUBLE,
            mean DOUBLE,
            std DOUBLE,
            best_solution MEDIUMBLOB,
            num_iteration INT,
            num_evaluation INT,
            seed INT)''')

def _create_summary_table(conn):
    cur = conn.cursor()
    cur.execute('''CREATE TABLE summary(
            method_id INT REFERENCES method(id),
            instance_id INT REFERENCES instance(id),
            iteration_id INT REFERENCES iteration(id))''')

def create_experiment(conn, experiment_name):
    '''Create database and tables for the experiment.
    Create a table "experiment" that contain the experimental
    summarization

    Parameters:
        - conn (object): mysql connection
        - experiment_name (str): name of the experiment
    '''
    cur = conn.cursor()
    cur.execute('CREATE DATABASE IF NOT EXISTS %s' % experiment_name)
    conn.select_db(experiment_name)
    _create_default_instance_table(conn)
    _create_default_method_table(conn)
    _create_default_iteration_table(conn)
    _create_summary_table(conn)

def drop_experiment(conn, experiment_name):
    '''Drop database contain experimental results

    Parameters:
        - conn (object): mysql connection
        - experiment_name (str): name of the experiment
    '''
    cur = conn.cursor()
    cur.execute('DROP DATABASE IF EXISTS %s' % experiment_name)

==> experiment_ltt-0.0.5-py3-none-any.whl: experiment/experiment.py <==
import yaml

def _create_default_instance_table(conn):
    cur = conn.cursor()
    cur.execute('''CREATE TABLE instance (
            id INT AUTO_INCREMENT PRIMARY KEY,
            name VARCHAR(512),
            kind VARCHAR(512))''')
    # Add unique constraint for all fields
    query = '''ALTER TABLE instance ADD UNIQUE unique_index (name,kind) '''
    cur.execute(query)
    conn.commit()

def _create_default_method_table(conn):
    cur = conn.cursor()
    cur.execute('''CREATE TABLE method(
            id INT AUTO_INCREMENT PRIMARY KEY)''')

def _create_default_iteration_table(conn):
    cur = conn.cursor()
    cur.execute('''CREATE TABLE iteration(
            id INT AUTO_INCREMENT PRIMARY KEY,
            best DOUBLE,
            mean DOUBLE,
            std DOUBLE,
            best_solution MEDIUMBLOB,
            num_iteration INT,
            num_evaluation INT,
            seed INT)''')

def _create_summary_table(conn):
    cur = conn.cursor()
    cur.execute('''CREATE TABLE summary(
            method_id INT REFERENCES method(id),
            instance_id INT REFERENCES instance(id),
            iteration_id INT REFERENCES iteration(id))''')

def create_experiment(conn, config):
    '''Create database and tables for the experiment.
    Create a table "experiment" that contain the experimental
    summarization

    Parameters:
        - conn (object): mysql connection
        - config (dict): contain db name
    '''
    cur = conn.cursor()
    cur.execute('CREATE DATABASE IF NOT EXISTS %s' % config['db'])
    conn.select_db(config['db'])
    _create_default_instance_table(conn)
    _create_default_method_table(conn)
    _create_default_iteration_table(conn)
    _create_summary_table(conn)
    if config['verbose']:
        print('[experiment|ok] create_experiment(%s)' % config['db'])

def drop_experiment(conn, config):
    '''Drop database contain experimental results

    Parameters:
        - conn (object): mysql connection
        - config (dict): contain db name
    '''
    cur = conn.cursor()
    cur.execute('DROP DATABASE IF EXISTS %s' % config['db'])
    if config['verbose']:
        print('[experiment|ok] drop_experiment(%s)' % config['db'])
